"""
Nether Framework

DO NOT USE IN PRODUCTION: This is a stub package.

This is a placeholder package to reserve the 'nether' name on PyPI.
The actual framework is currently UNDER DEVELOPMENT.

"""

__version__ = "0.0.1"

print("WARNING: This is a placeholder package for the Nether framework.")
print("The actual framework is under development.")
print("Check https://github.com/ariuna-systems/nether for updates.")
